#pragma once
#include <Engine/types/entity/Sprite.h>

namespace Engine {
    class InstancedSprite;
}

class Engine::InstancedSprite : public Sprite {
private:
    std::string texture_path;
public:
    [[nodiscard]] std::string GetTextureFilesystemPath() const { return texture_path; }
    [[nodiscard]] Texture* GetTexture() const override;
public:
    /** The Texture *must* be instanced. The alpha-mask *can* be instanced.
     * You can use SetAlphaMask() to change to a unique one.
     * To change back to the instanced one if there is one, You can SetAlphaMask(nullptr);
     * If there is no instanced alpha mask and unique alpha mask is set
     * to nullptr, Then there is no alpha mask. - Redacted.
    */
    ~InstancedSprite() override;
    InstancedSprite(const Vector2& position, unsigned int layer, const std::string& instanced_texture_filesystem_path,
                    const Vector2& origin = {0, 0}, float face_angle = 0.0f, const Color4& base_color = Colors::White, Texture* unique_alpha_mask = nullptr, const std::string& instanced_alpha_mask_filesystem_path = "")
                    : Sprite(position, origin, layer, face_angle, base_color, nullptr, unique_alpha_mask), texture_path(instanced_texture_filesystem_path) {}
};
